#! /usr/lib/veetest/veetest -r
(revision "A.00.00")
(date "Thu 02/May/1991")
(component 0 "Context"
 (name "Set Mappings Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "FromSpectrum"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Spec Data")
     (tag "Spec Data")
     (requires
      (datatype Spectrum)
     )
     (lock constraints)
    )
    (output 1
     (type data)
     (name "Pcx Ary")
     (tag "Pcx Ary")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Start")
     (tag "Start")
     (lock name constraints)
    )
    (output 3
     (type data)
     (name "Stop")
     (tag "Stop")
     (lock name constraints)
    )
   )
   (implementation
    (component freqMode "Start/Stop Freq")
   )
   (views
    (icon
     (origin 83 408)
     (extent 154 64)
     (iconImage unbuild.icon)
    )
    (detail
     (origin 544 410)
     (extent 173 100)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "FromPComplex"
   (name "UnBuild PComplex")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "PComplex")
     (requires
      (datatype PComplex)
     )
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Mag")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Phase")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 83 318)
     (extent 154 64)
     (iconImage unbuild.icon)
    )
    (detail
     (origin 615 395)
     (extent 80 70)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "Formula"
   (name "maxX(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "maxX(x)")
   )
   (views
    (icon
     (origin 301 318)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "Formula"
   (name "max(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "max(x)")
   )
   (views
    (icon
     (origin 441 428)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "ToFunction"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "InArray")
     (tag "InArray")
     (lock constraints)
    )
    (input 2
     (type data)
     (name "Map From 1")
     (tag "Map From 1")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (lock constraints)
     (optional yes)
    )
    (input 3
     (type data)
     (name "Map To 1")
     (tag "Map To 1")
     (requires
      (datatype Real)
      (shape "Scalar")
     )
     (lock constraints)
     (optional yes)
    )
    (output 1
     (type data)
     (name "OutFunc")
     (tag "OutFunc")
     (lock constraints)
    )
    (buffers in
     (buffer "Map From 1")
     (buffer "Map To 1")
    )
   )
   (implementation
    (component numDims 1)
    (component xMappings "Linear")
    (component mapFroms "0")
    (component mapTos "6450")
   )
   (views
    (icon
     (origin 291 408)
     (extent 118 64)
     (iconImage build.icon)
    )
    (detail
     (origin 542 153)
     (extent 347 154)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 5 "YPlot"
   (name "Magnitude Spectrum")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Trace1")
     (lock constraints)
    )
    (input 2
     (type control)
     (name "Auto Scale")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component tracePin 1)
    (component graphMode freqmag)
   )
   (views
    (icon
     (iconImage display.icon)
    )
    (detail
     (origin 610 132)
     (extent 360 296)
     (displayMode scrollGraph)
     (graphType cartesian)
     (gridType grid)
     (scale 0
      (name "Mag")
      (domainName "Freq")
      (color 0x909090)
      (show 1)
      (range 0 250000 4 linear)
     )
     (domain 0 7000 4 linear)
     (trace 0 onScale 0
      (name "Trace1")
      (color 0xffdd00)
      (lineType 1)
      (pointType 0)
     )
    )
    (active detail)
   )
  )
  (component 6 "TextDisplay"
   (name "Max Freq Component, Hz")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 208 0)
    )
    (detail
     (origin 619 473)
     (extent 282 35)
    )
    (active detail)
   )
  )
  (component 7 "TextDisplay"
   (name "Max Magnitude")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 127 0)
    )
    (detail
     (origin 619 553)
     (extent 282 35)
    )
    (active detail)
   )
  )
  (component 8 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 482 639)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 9 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 203 491)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 367 498)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "RepeatUntilBreak"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Continuous")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 125 418)
       (extent 110 64)
       (iconImage loop.icon)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "Context"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "NotePad")
       (interface
       )
       (implementation
        (component text 30 9
         PURPOSE: Shows how to retrieve meaningful information from a spectrum data type using
                  the Unbuild Spectrum, UnBuild PComplex, and Set Mappings objects.  All these 
                  objects are under the main menu choice, Data. 
         
         USER INPUT REQUIRED: Press "Run" to start execution.
         
         EXPLANATION: This example builds a complex, random waveform by continuosly adding sine
                      waves with random amplitudes and phase shifts and frequencies from 5 to 5000
                      Hz.  After the waveform has been constructed, it is sent to the fft(x) 
                      object.  The input to the fft(x) object is the HP Vee data type, Waveform.
                      The output from the fft(x) object is the HP Vee data type, Spectrum.  It is
                      often necessary to find the frequency of the main component of the waveform.
                      This main component can be seen on the Magnitude Spectrum display, and can be
                      found exactly by using the markers (under the display's object menu).
                      
                      To find that main component programmatically requires that the Spectrum
                      data type be disassembled, or unbuilt.  The UnBuild Spectrum object receives
                      the spectrum and unbuilds it to an array of PCpmplex (polar complex) and
                      also outputs the start and stop frequencies.  A PComplex represents the 
                      magnitude and phase of each point on the spectrum.  The array of PComplex
                      must be unbuilt to get an array of magnitudes, i.e. an array of real numbers.
                      At this point the array of magnitudes has lost the original mapping of
                      PComplex numbers to frequencies.  The Set Mappings object is used to build
                      that mapping.  The inputs to the Set Mappings object are the array of reals,
                      and the start and stop frequencies output from the UnBuild Spectrum object.
                      Now we have an array of reals, i.e. magnitudes, mapped to a range of 
                      frequencies.  The maxX(x) object takes any mapped function and returns the
                      X value of the maximum Y value, in this case the maximum frequency component.
                      
         
        )
       )
       (views
        (description 2 9
         This notepad is displayed as a Show on Execute
         panel to present the information to the reader.
        )
        (icon
         (origin 200 205)
         (extent 78 25)
        )
        (detail
         (origin 36 162)
         (extent 848 437)
         (editing disabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (description 7 9
         This tiny "thread" begins running when the 
         enclosing UserObject is executed.  When the user
         acknowledges the OK/DONE button, there is nothing
         left to execute, so the thread ends.  Since there
         are not other threads running, the User Object
         is completed and will exit, removing the Show on
         Execute pop-up display.
        )
        (icon
         (origin 211 272)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 55 78)
       (extent 877 570)
       (panel
        (origin 14 314)
        (extent 873 532)
        (widget 1 icon
         (title off)
         (origin 413 799)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 28 327)
         (extent 845 461)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 342 568)
       (extent 217 25)
      )
      (detail
       (origin 57 160)
       (extent 866 520)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D2:1 D0:0)
     (connect D3:0 D0:1)
     (connect D0:1 D1:1)
     (connect D1:1 D3:0)
    )
   )
   (views
    (icon
     (origin 465 408)
     (extent 110 25)
    )
    (panel
     (origin 81 642)
     (extent 319 77)
     (widget 0 icon
      (title off)
      (origin 183 655)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 265)
     (extent 912 591)
     (configuration
      (connect D2:1 D0:0
       (Point 237 450)
       (Point 260 450)
       (Point 260 488)
      )
      (connect D3:0 D0:1
       (Point 450 595)
       (Point 450 610)
       (Point 180 610)
       (Point 180 510)
       (Point 200 510)
      )
      (connect D0:1 D1:1
       (Point 319 510)
       (Point 364 510)
      )
      (connect D1:1 D3:0
       (Point 415 500)
       (Point 450 500)
       (Point 450 565)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (component 10 "Context"
   (name "Create Random Waveform")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "ForRange"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component from 5)
      (component thru 5005)
      (component step 50)
     )
     (views
      (icon
       (origin 45 188)
       (extent 110 64)
       (iconImage loop.icon)
      )
      (detail
       (origin 5 157)
       (extent 170 86)
      )
      (active icon)
     )
    )
    (component 1 "RandomNumber"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Rand Val")
       (lock name constraints)
      )
     )
     (implementation
      (component lowerLimit 1)
      (component upperLimit 360)
     )
     (views
      (icon
       (origin 107 328)
       (extent 127 25)
      )
      (detail
       (origin 39 300)
       (extent 222 60)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Formula"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (input 2
       (type data)
       (name "B")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Result")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr 1 "A/B")
     )
     (views
      (icon
       (origin 201 208)
       (extent 78 64)
       (iconImage formula.icon)
      )
      (detail
       (origin 261 228)
       (extent 88 104)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "VFunctionGenerator"
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "Frequency")
       (tag "Frequency")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
      )
      (input 2
       (type data)
       (name "Amplitude")
       (tag "Amplitude")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
      )
      (input 3
       (type data)
       (name "Phase")
       (tag "Phase")
       (requires
        (datatype Real)
        (shape "Scalar")
       )
       (lock constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
      (buffers in
       (buffer "Frequency")
       (buffer "Amplitude")
       (buffer "Phase")
      )
     )
     (implementation
      (component function Cosine)
      (component frequency 5005)
      (component amplitude 27.55331204943281)
      (component dcOffset 0)
      (component phaseShift 181.6478538413326)
      (component numPoints 256)
      (component interval 0.02)
      (component degRad Deg)
      (component errorOnAlias 1)
     )
     (views
      (icon
       (origin 314 168)
       (extent 172 64)
       (iconImage virtual.icon)
      )
      (detail
       (origin 276 141)
       (extent 239 198)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 4 "Formula"
     (name " + ")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "X")
       (lock name constraints)
      )
      (input 2
       (type data)
       (name "Y")
       (lock name constraints)
      )
      (output 1
       (type data)
       (name "Result")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked yes)
      (component expr 1 "X+Y")
     )
     (views
      (icon
       (origin 507 198)
       (extent 46 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 5 "Start"
     (interface
      (sequence out)
     )
     (implementation
     )
     (views
      (icon
       (origin 67 122)
       (extent 67 37)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (configuration
     (connect D5:0 D0:0)
     (connect D0:1 D1:0)
     (connect D0:1 D2:1)
     (connect D1:1 D2:2)
     (connect D0:1 D3:1)
     (connect D2:1 D3:2)
     (connect D1:1 D3:3)
     (connect D3:1 D4:1)
     (connect D4:1 D4:2)
     (connect D4:1 O1:1)
    )
   )
   (views
    (icon
     (origin 56 128)
     (extent 208 25)
    )
    (detail
     (origin 37 113)
     (extent 566 255)
     (configuration
      (connect D5:0 D0:0
       (Point 100 161)
       (Point 100 185)
      )
      (connect D0:1 D1:0
       (Point 157 220)
       (Point 170 220)
       (Point 170 325)
      )
      (connect D0:1 D2:1
       (Point 157 220)
       (Point 198 220)
      )
      (connect D1:1 D2:2
       (Point 236 340)
       (Point 250 340)
       (Point 250 310)
       (Point 180 310)
       (Point 180 260)
       (Point 198 260)
      )
      (connect D0:1 D3:1
       (Point 157 220)
       (Point 180 220)
       (Point 180 180)
       (Point 311 180)
      )
      (connect D2:1 D3:2
       (Point 281 240)
       (Point 290 240)
       (Point 290 200)
       (Point 311 200)
      )
      (connect D1:1 D3:3
       (Point 236 340)
       (Point 250 340)
       (Point 250 300)
       (Point 300 300)
       (Point 300 220)
       (Point 311 220)
      )
      (connect D3:1 D4:1
       (Point 488 200)
       (Point 504 200)
      )
      (connect D4:1 D4:2
       (Point 555 210)
       (Point 570 210)
       (Point 570 240)
       (Point 490 240)
       (Point 490 220)
       (Point 504 220)
      )
      (connect D4:1 O1:1
       (Point 555 210)
       (Point 570 210)
       (Point 570 250)
       (Point 600 250)
      )
     )
    )
    (terminals on)
    (active icon)
   )
  )
  (component 11 "ExitProcess"
   (interface
    (sequence in)
   )
   (implementation
    (comp code 0)
   )
   (views
    (icon
     (origin 137 188)
     (extent 46 25)
    )
    (detail
     (origin 340 513)
     (extent 120 34)
    )
    (active icon)
   )
  )
  (component 12 "Formula"
   (name "fft(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "fft(x)")
   )
   (views
    (icon
     (origin 331 128)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (configuration
   (connect D12:1 D0:1)
   (connect D0:1 D1:1)
   (connect D4:1 D2:1)
   (connect D4:1 D3:1)
   (connect D1:1 D4:1)
   (connect D0:2 D4:2)
   (connect D0:3 D4:3)
   (connect D12:1 D5:1)
   (connect D12:0 D5:2)
   (connect D2:1 D6:1)
   (connect D3:1 D7:1)
   (connect D10:0 D11:0)
   (connect D10:1 D12:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1043 828)
   (configuration
    (connect D12:1 D0:1
     (Point 411 140)
     (Point 430 140)
     (Point 430 200)
     (Point 420 200)
     (Point 420 230)
     (Point 50 230)
     (Point 50 440)
     (Point 80 440)
    )
    (connect D0:1 D1:1
     (Point 239 420)
     (Point 250 420)
     (Point 250 400)
     (Point 60 400)
     (Point 60 350)
     (Point 80 350)
    )
    (connect D4:1 D2:1
     (Point 411 440)
     (Point 430 440)
     (Point 430 390)
     (Point 280 390)
     (Point 280 330)
     (Point 298 330)
    )
    (connect D4:1 D3:1
     (Point 411 440)
     (Point 438 440)
    )
    (connect D1:1 D4:1
     (Point 239 330)
     (Point 260 330)
     (Point 260 420)
     (Point 288 420)
    )
    (connect D0:2 D4:2
     (Point 239 440)
     (Point 288 440)
    )
    (connect D0:3 D4:3
     (Point 239 460)
     (Point 288 460)
    )
    (connect D12:1 D5:1
     (Point 411 140)
     (Point 430 140)
     (Point 430 200)
     (Point 607 200)
    )
    (connect D12:0 D5:2
     (Point 370 155)
     (Point 370 210)
     (Point 560 210)
     (Point 560 360)
     (Point 607 360)
    )
    (connect D2:1 D6:1
     (Point 381 330)
     (Point 550 330)
     (Point 550 490)
     (Point 616 490)
    )
    (connect D3:1 D7:1
     (Point 521 440)
     (Point 540 440)
     (Point 540 570)
     (Point 616 570)
    )
    (connect D10:0 D11:0
     (Point 160 155)
     (Point 160 185)
    )
    (connect D10:1 D12:1
     (Point 266 140)
     (Point 328 140)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
